@@ -293,6 +293,7 @@ class PyDMArchiverTimePlot(PyDMTimePlot):
                         max_x = self._starting_timestamp
                 requested_seconds = max_x - min_x
                 if requested_seconds <= 5:
+                    self._archive_request_queued = False
                     continue  # Avoids noisy requests when first rendering the plot
                 # Max amount of raw data to return before using optimized data
                 max_data_request = int(0.80 * self.getArchiveBufferSize())
@@ -328,6 +329,14 @@ class PyDMArchiverTimePlot(PyDMTimePlot):
             return
         self._time_span = value
 
+    def clearCurves(self) -> None:
+        """ Clear all curves from the plot """
+        for curve in self._curves:
+            # Need to clear out any bars from optimized data, then super() can handle the rest
+            if not curve.error_bar_needs_set:
+                curve.getViewBox().removeItem(curve.error_bar_item)
+        super().clearCurves()
+
     def getCurves(self) -> List[str]:
         """
         Dump and return the current list of curves and each curve's settings into a list
