@@ -1,7 +1,7 @@
 import weakref
 from collections import Counter
 from pyqtgraph import AxisItem, PlotDataItem, PlotItem, ViewBox
-from typing import List
+from typing import List, Optional
 from .multi_axis_viewbox import MultiAxisViewBox
 from .multi_axis_viewbox_menu import MultiAxisViewBoxMenu
 from ..utilities import is_qt_designer
@@ -76,14 +76,12 @@ class MultiAxisPlot(PlotItem):
         # Create a new view box to link this axis with
         self.axes[str(name)] = {'item': axis, 'pos': None}  # The None will become an actual position in rebuildLayout() below
         view = MultiAxisViewBox()
-        view.menu = MultiAxisViewBoxMenu(view)
         view.setYRange(minRange, maxRange)
         view.enableAutoRange(axis=ViewBox.XAxis, enable=enableAutoRangeX)
         view.enableAutoRange(axis=ViewBox.YAxis, enable=enableAutoRangeY)
         self.axes['bottom']['item'].linkToView(view)  # Ensure the x axis will update when the view does
 
         view.setMouseMode(self.vb.state['mouseMode'])  # Ensure that mouse behavior is consistent between stacked views
-        self.connectMenuSignals(view.menu)
         axis.linkToView(view)
 
         if plotDataItem is not None:
@@ -129,8 +127,14 @@ class MultiAxisPlot(PlotItem):
         """
         view_box_menu.sigMouseModeChanged.connect(self.changeMouseMode)
         view_box_menu.sigXAutoRangeChanged.connect(self.updateXAutoRange)
+        view_box_menu.sigYAutoRangeChanged.connect(self.updateYAutoRange)
         view_box_menu.sigRestoreRanges.connect(self.restoreAxisRanges)
         view_box_menu.sigSetAutorange.connect(self.setPlotAutoRange)
+        view_box_menu.sigInvertAxis.connect(self.invertAxis)
+        view_box_menu.sigVisibleOnly.connect(self.setPlotAutoRangeVisibleOnly)
+        view_box_menu.sigAutoPan.connect(self.setPlotAutoPan)
+        view_box_menu.sigXManualRange.connect(self.setXRange)
+        view_box_menu.sigYManualRange.connect(self.setYRange)
 
     def updateStackedViews(self):
         """
@@ -178,7 +182,6 @@ class MultiAxisPlot(PlotItem):
         plotDataItem.setFftMode(self.ctrl.fftCheck.isChecked())
         plotDataItem.setDownsampling(*self.downsampleMode())
         plotDataItem.setClipToView(self.clipToViewMode())
-        plotDataItem.setPointMode(self.pointMode())
 
         # Add to average if needed
         self.updateParamList()
@@ -345,6 +348,53 @@ class MultiAxisPlot(PlotItem):
             stackedView.enableAutoRange(x=x, y=y)
         self.getViewBox().enableAutoRange(x=x, y=y)
 
+    def setPlotAutoPan(self, auto_pan_x: Optional[bool] = None, auto_pan_y: Optional[bool] = None) -> None:
+        """
+        Toggle pan only mode (no scaling) when auto range is enabled.
+
+        Parameters
+        ----------
+        auto_pan_x : bool, optional
+            Whether or not the x-axis should be set to auto pan. If omitted, will be unchanged from current value.
+        auto_pan_y : bool, optional
+            Whether or not the y-axis should be set to auto pan. If omitted, will be unchanged from current value.
+        """
+        for stackedView in self.stackedViews:
+            stackedView.setAutoPan(x=auto_pan_x, y=auto_pan_y)
+
+    def setPlotAutoRangeVisibleOnly(self, visible_only_x: Optional[bool] = None,
+                                    visible_only_y: Optional[bool] = None) -> None:
+        """
+        Toggle if auto range should use only visible data when calculating the range to show
+
+        Parameters
+        ----------
+        visible_only_x : bool, optional
+            Whether or not the x-axis should be set to visible only. If omitted, will be unchanged from current value.
+        visible_only_y : bool, optional
+            Whether or not the y-axis should be set to visible only. If omitted, will be unchanged from current value.
+        """
+        for stackedView in self.stackedViews:
+            stackedView.setAutoVisible(x=visible_only_x, y=visible_only_y)
+
+
+    def invertAxis(self, axis: int, inverted: bool) -> None:
+        """
+        Toggle whether or not the input axis should be inverted.
+
+        Parameters
+        ----------
+        axis : int
+            An int associated with the axis to modify. Must be either ViewBox.XAxis or ViewBox.YAxis from pyqtgraph
+        inverted : bool
+            True if we are inverting the axis, False if not
+        """
+        for stackedView in self.stackedViews:
+            if axis == ViewBox.XAxis:
+                stackedView.invertX(inverted)
+            elif axis == ViewBox.YAxis:
+                stackedView.invertY(inverted)
+
     def removeItem(self, item):
         """
         Remove an item from this plot. An override of the pyqtgraph implementation which assumes
@@ -476,6 +526,12 @@ class MultiAxisPlot(PlotItem):
         for stackedView in self.stackedViews:
             stackedView.enableAutoRange(ViewBox.XAxis, val)
 
+    def updateYAutoRange(self, val):
+        """ Update the autorange values for the y-axis on all view boxes """
+        self.vb.enableAutoRange(ViewBox.YAxis, val)
+        for stackedView in self.stackedViews:
+            stackedView.enableAutoRange(ViewBox.YAxis, val)
+
     def updateLogMode(self) -> None:
         """ Toggle log mode on or off for each item in the plot """
         x = self.ctrl.logXCheck.isChecked()
